import { Emitter } from 'mitt';
import { Handler } from 'mitt';

declare type AvailableLanguages = 'en' | 'pt' | 'de' | 'es' | 'fr' | 'it' | 'nl' | 'sv';

declare type AvailableThemes = 'dark' | 'red' | 'pink' | 'purple' | 'deep-purple' | 'indigo' | 'blue' | 'light-blue' | 'cyan' | 'teal' | 'green' | 'light-green' | 'lime' | 'yellow' | 'amber' | 'orange' | 'deep-orange' | 'brown' | 'blue-grey';

declare type EmitterClientEvents = {
    [Events.OPEN]: {
        element: Picker['target']['element'];
    };
    [Events.CLOSE]: {
        element: Picker['target']['element'];
    };
    [Events.CHANGE]: {
        hour: Picker['hour'];
        minute: Picker['minute'];
        element: Picker['target']['element'];
    };
};

declare type EmitterEvents = {
    [Events.START_FADE_IN]: Picker['target']['element'];
    [Events.START_FADE_OUT]: Picker['target']['element'];
    [Events.END_FADE_IN]: Picker['target']['element'];
    [Events.END_FADE_OUT]: Picker['target']['element'];
};

declare const enum Events {
    OPEN = "open",
    CLOSE = "close",
    CHANGE = "change",
    START_FADE_IN = "start-fade-in",
    END_FADE_IN = "end-fade-in",
    START_FADE_OUT = "start-fade-out",
    END_FADE_OUT = "end-fade-out"
}

declare type Options = {
    lang: AvailableLanguages;
    theme: AvailableThemes;
};

declare type Picker = {
    options: Options;
    target: {
        element: HTMLElement;
        offset: {
            width: number;
            height: number;
            top: number;
            bottom: number;
            right: number;
            left: number;
        };
    };
    hour: string;
    minute: string;
    opened: boolean;
    requestAnimationId: number;
    closeWhen: {
        hour: boolean;
        minute: boolean;
    };
    collection: {
        hours: NodeListOf<HTMLAnchorElement>;
        minutes: NodeListOf<HTMLAnchorElement>;
    };
    container: {
        element: HTMLDivElement;
        dragElement: HTMLElement;
        lastX: number;
        lastY: number;
        currentX: number;
        currentY: number;
        x: number;
        y: number;
        size: {
            width: number;
            height: number;
        };
    };
};

declare class TimePicker {
    container: Picker['container']['element'];
    protected options: Options;
    protected targetElement: HTMLElement;
    protected emitter: Emitter<EmitterEvents & EmitterClientEvents>;
    protected picker: Picker;
    constructor(target: string | HTMLElement, opts?: Partial<Options>);
    private triggerShow;
    private handleAnchorClick;
    show(): void;
    hide(): void;
    on<Key extends keyof EmitterClientEvents>(type: Key, handler: Handler<EmitterClientEvents[Key]>): void;
    private getHour;
    private getMinute;
}
export default TimePicker;

export { }
